package cn.efunbox.audio.impl.res;

import cn.efunbox.audio.entity.res.ResAlbum;
import cn.efunbox.audio.page.ResOnePage;
import cn.efunbox.audio.repository.res.ResAlbumRepository;
import cn.efunbox.audio.service.res.ContenUpdateService;
import cn.efunbox.audio.utils.ResApiCode;
import cn.efunbox.audio.utils.ResApiResult;
import cn.efunbox.audio.vo.res.ContentUpdateVO;
import cn.efunbox.audio.vo.res.ContentVO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Objects;

/**
 * ContenUpdateServiceImpl
 * Created by wangys on
 */
@Service
public class ContenUpdateServiceImpl implements ContenUpdateService {
    @Autowired
    private ResAlbumRepository resAlbumRepository;
    @Override
    public ResApiResult getContentUpdateList(String beginTime, String order, Integer pageNum, Integer pageSize) throws ParseException {
        if (StringUtils.isNotBlank(order)) {
            if (StringUtils.equals(order, "asc") || StringUtils.equals(order, "desc")) {
            } else {
                return ResApiResult.error(ResApiCode.NOT_FOUND);
            }
        }
        int startNum = 0;
        int startSize = 20;
        if (pageNum != null || pageSize != null) {
            if (pageNum < 0 || pageSize < 0) {
                return ResApiResult.error(ResApiCode.NOT_FOUND);
            }
            startNum = (pageNum - 1) * pageSize;
            startSize = pageNum * pageSize;
        }
        DateFormat dateFormat = new SimpleDateFormat("yyyymmddhhmmss");
        Date parse = null;
        if (StringUtils.isNotBlank(beginTime)) {
            parse = dateFormat.parse(beginTime);
        } else {
            long time = 24 * 60 * 60 * 1000;
            time = System.currentTimeMillis() - time;
            parse = new Date(time);
        }
        DateFormat dateFormat2 = new SimpleDateFormat("yyyy-MM-dd hh:mm:ss");
        String format = dateFormat2.format(parse);
        List<ResAlbum> resCategoryLimit3 = resAlbumRepository.getResCategoryLimit3(format);
        if (Objects.isNull(resCategoryLimit3)) {
            return ResApiResult.error(ResApiCode.NOT_FOUND);
        }
        int size = resCategoryLimit3.size();
        List<ResAlbum> resCategoryLimit = null;
        if (StringUtils.equals(order, "desc")) {
            resCategoryLimit = resAlbumRepository.getResCategoryLimit(format, startNum, startSize);
        } else {
            resCategoryLimit = resAlbumRepository.getResCategoryLimit2(format, startNum, startSize);
        }
        ContentUpdateVO contentUpdateVO = new ContentUpdateVO();
        List<ContentVO> list = new ArrayList<>();
        resCategoryLimit.forEach(resAlbum -> {
            ContentVO contentVO = getContentVO(resAlbum);
            list.add(contentVO);
        });
        if (Objects.isNull(pageNum)){
            contentUpdateVO.setPageNum(1);
        }else {
            contentUpdateVO.setPageNum(pageNum);
        }
        contentUpdateVO.setPageSize(resCategoryLimit.size());
        contentUpdateVO.setPageTotal(size);
        contentUpdateVO.setContentList(list);
        return ResApiResult.ok(contentUpdateVO);
    }
    private ContentVO getContentVO(ResAlbum resAlbum) {
        ContentVO contentVO = new ContentVO();
        contentVO.setContentId(resAlbum.getContentId());
        contentVO.setContentName(resAlbum.getContentName());
        contentVO.setShortrecommend(resAlbum.getShortrecommend());
        contentVO.setLongrecommend(resAlbum.getLongrecommend());
        contentVO.setAuthor(resAlbum.getAuthor());
        contentVO.setReaderName(resAlbum.getReaderName());
        contentVO.setContentPicUrl(resAlbum.getContentPicUrl());
        contentVO.setChapterCount(resAlbum.getChapterCount());
        contentVO.setPayMode(resAlbum.getPayMode());
        contentVO.setPrice(resAlbum.getPrice());
        contentVO.setPlaycount(resAlbum.getPlaycount());
        contentVO.setUpdateType(resAlbum.getRenewal());
        contentVO.setStatus(resAlbum.getIsDel());
        Date getModified = resAlbum.getGmtModified();
        DateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        String format1 = format.format(getModified);
        contentVO.setUpdatetime(format1);
        contentVO.setMediaType(resAlbum.getMediaType());
        Date gmtCreated = resAlbum.getGmtCreated();
        String format2 = format.format(gmtCreated);
        contentVO.setPublishTime(format2);
        return contentVO;
    }
}
